@@ -21,6 +21,7 @@
 #define ALSOURCE_H
 
 #include "src/audio/iaudiosource.h"
+#include "src/util/compatiblerecursivemutex.h"
 #include <QMutex>
 #include <QObject>
 
@@ -43,7 +44,7 @@ public:
 private:
     OpenAL& audio;
     bool killed = false;
-    mutable QMutex killLock;
+    mutable CompatibleRecursiveMutex killLock;
 };
 
 #endif // ALSOURCE_H
